==> ejc-law-api-3.0.0-20230913.071538-67-sources.jar: com/ejianc/business/law/vo/ProsecutionInfoRegisterVO.java <==
package com.ejianc.business.law.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 起诉案件审理信息登记表
 * 
 * @author generator
 * 
 */
public class ProsecutionInfoRegisterVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String operatorCode; // 经办人联系方式
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long firstCourtId; // 法院
    private String firstCourtName; // 法院名称
    private String firstJudgeName; // 法官名称
    private String firstJudgeCode; // 法官联系方式
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstStartDate; // 开庭日期
    private String firstCode; // 案号
    private Long firstTypeId; // 审理程序
    private String firstTypeName; // 审理程序名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstEndDate; // 结案日期
    private Long firstResultId; // 案件结果
    private String firstResultName; // 案件结果
    private BigDecimal firstEndAmount; // 结案金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstAppealDate; // 上诉截至日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstLastDate; // 再审截至日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstPayDate; // 支付时间
    private Integer hearCount; // 审理阶段（0未审理，1一审，2二审，3再审）
    private Long caseId; // 案件编号
    private String caseName; // 案件编号名称
    private BigDecimal appealAmount; // 上诉金额
    private BigDecimal thirdAmount; // 再审金额
    private String appealAmountRemark; // 上诉金额备注
    private String thirdAmountRemark; // 再审金额备注
    private String disputeType; // 纠纷类型
    private String disputeTypeName; // 纠纷类型名称
    private Long plaintiffMainId; // 主原告id
    private String plaintiffMainName; // 主原告名称
    private Long departmentId; // 涉案项目部
    private String departmentName; // 涉案项目部名称
    private Long projectId; // 工程
    private String projectName; // 工程名称
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getFirstCourtId() {
        return firstCourtId;
    }

    public void setFirstCourtId(Long firstCourtId) {
        this.firstCourtId = firstCourtId;
    }
    public String getFirstCourtName() {
        return firstCourtName;
    }

    public void setFirstCourtName(String firstCourtName) {
        this.firstCourtName = firstCourtName;
    }
    public String getFirstJudgeName() {
        return firstJudgeName;
    }

    public void setFirstJudgeName(String firstJudgeName) {
        this.firstJudgeName = firstJudgeName;
    }
    public String getFirstJudgeCode() {
        return firstJudgeCode;
    }

    public void setFirstJudgeCode(String firstJudgeCode) {
        this.firstJudgeCode = firstJudgeCode;
    }
    public Date getFirstStartDate() {
        return firstStartDate;
    }

    public void setFirstStartDate(Date firstStartDate) {
        this.firstStartDate = firstStartDate;
    }
    public String getFirstCode() {
        return firstCode;
    }

    public void setFirstCode(String firstCode) {
        this.firstCode = firstCode;
    }
    public Long getFirstTypeId() {
        return firstTypeId;
    }

    public void setFirstTypeId(Long firstTypeId) {
        this.firstTypeId = firstTypeId;
    }
    public String getFirstTypeName() {
        return firstTypeName;
    }

    public void setFirstTypeName(String firstTypeName) {
        this.firstTypeName = firstTypeName;
    }
    public Date getFirstEndDate() {
        return firstEndDate;
    }

    public void setFirstEndDate(Date firstEndDate) {
        this.firstEndDate = firstEndDate;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getFirstResultId() {
        return firstResultId;
    }
    @ReferDeserialTransfer
    public void setFirstResultId(Long firstResultId) {
        this.firstResultId = firstResultId;
    }
    public String getFirstResultName() {
        return firstResultName;
    }

    public void setFirstResultName(String firstResultName) {
        this.firstResultName = firstResultName;
    }
    public BigDecimal getFirstEndAmount() {
        return firstEndAmount;
    }

    public void setFirstEndAmount(BigDecimal firstEndAmount) {
        this.firstEndAmount = firstEndAmount;
    }
    public Date getFirstAppealDate() {
        return firstAppealDate;
    }

    public void setFirstAppealDate(Date firstAppealDate) {
        this.firstAppealDate = firstAppealDate;
    }
    public Date getFirstLastDate() {
        return firstLastDate;
    }

    public void setFirstLastDate(Date firstLastDate) {
        this.firstLastDate = firstLastDate;
    }
    public Date getFirstPayDate() {
        return firstPayDate;
    }

    public void setFirstPayDate(Date firstPayDate) {
        this.firstPayDate = firstPayDate;
    }
    public Integer getHearCount() {
        return hearCount;
    }

    public void setHearCount(Integer hearCount) {
        this.hearCount = hearCount;
    }
    @ReferSerialTransfer(referCode = "law-prosecution-case-register")
    public Long getCaseId() {
        return caseId;
    }
    @ReferDeserialTransfer
    public void setCaseId(Long caseId) {
        this.caseId = caseId;
    }
    public String getCaseName() {
        return caseName;
    }

    public void setCaseName(String caseName) {
        this.caseName = caseName;
    }
    public BigDecimal getAppealAmount() {
        return appealAmount;
    }

    public void setAppealAmount(BigDecimal appealAmount) {
        this.appealAmount = appealAmount;
    }
    public BigDecimal getThirdAmount() {
        return thirdAmount;
    }

    public void setThirdAmount(BigDecimal thirdAmount) {
        this.thirdAmount = thirdAmount;
    }
    public String getAppealAmountRemark() {
        return appealAmountRemark;
    }

    public void setAppealAmountRemark(String appealAmountRemark) {
        this.appealAmountRemark = appealAmountRemark;
    }
    public String getThirdAmountRemark() {
        return thirdAmountRemark;
    }

    public void setThirdAmountRemark(String thirdAmountRemark) {
        this.thirdAmountRemark = thirdAmountRemark;
    }
    public String getDisputeType() {
        return disputeType;
    }

    public void setDisputeType(String disputeType) {
        this.disputeType = disputeType;
    }
    public String getDisputeTypeName() {
        return disputeTypeName;
    }

    public void setDisputeTypeName(String disputeTypeName) {
        this.disputeTypeName = disputeTypeName;
    }
    public Long getPlaintiffMainId() {
        return plaintiffMainId;
    }

    public void setPlaintiffMainId(Long plaintiffMainId) {
        this.plaintiffMainId = plaintiffMainId;
    }
    public String getPlaintiffMainName() {
        return plaintiffMainName;
    }

    public void setPlaintiffMainName(String plaintiffMainName) {
        this.plaintiffMainName = plaintiffMainName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    
}

==> ejc-law-api-3.0.0-20250213.101320-125-sources.jar: com/ejianc/business/law/vo/ProsecutionInfoRegisterVO.java <==
package com.ejianc.business.law.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 起诉案件审理信息登记表
 *
 * @author generator
 */
public class ProsecutionInfoRegisterVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String operatorCode; // 经办人联系方式
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long firstCourtId; // 法院
    private String firstCourtName; // 法院名称
    private String firstJudgeName; // 法官名称
    private String firstJudgeCode; // 法官联系方式
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstStartDate; // 开庭日期
    private String firstCode; // 案号
    private Long firstTypeId; // 审理程序
    private String firstTypeName; // 审理程序名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstEndDate; // 结案日期
    private Long firstResultId; // 案件结果
    private String firstResultName; // 案件结果
    private BigDecimal firstEndAmount; // 结案金额
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstAppealDate; // 上诉截至日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstLastDate; // 再审截至日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date firstPayDate; // 支付时间
    private Integer hearCount; // 审理阶段（0未审理，1一审，2二审，3再审）
    private Long caseId; // 案件编号
    private String caseName; // 案件编号名称
    private BigDecimal appealAmount; // 上诉金额
    private BigDecimal thirdAmount; // 再审金额
    private String appealAmountRemark; // 上诉金额备注
    private String thirdAmountRemark; // 再审金额备注
    private String disputeType; // 纠纷类型
    private String disputeTypeName; // 纠纷类型名称
    private Long plaintiffMainId; // 主原告id
    private String plaintiffMainName; // 主原告名称
    private Long departmentId; // 涉案项目部
    private String departmentName; // 涉案项目部名称
    private Long projectId; // 工程
    private String projectName; // 工程名称
    private BigDecimal lng; // 经度
    private BigDecimal lat; // 维度
    private String areaName; // 区域
    private String area; // 区域

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }

    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getFirstCourtId() {
        return firstCourtId;
    }

    public void setFirstCourtId(Long firstCourtId) {
        this.firstCourtId = firstCourtId;
    }

    public String getFirstCourtName() {
        return firstCourtName;
    }

    public void setFirstCourtName(String firstCourtName) {
        this.firstCourtName = firstCourtName;
    }

    public String getFirstJudgeName() {
        return firstJudgeName;
    }

    public void setFirstJudgeName(String firstJudgeName) {
        this.firstJudgeName = firstJudgeName;
    }

    public String getFirstJudgeCode() {
        return firstJudgeCode;
    }

    public void setFirstJudgeCode(String firstJudgeCode) {
        this.firstJudgeCode = firstJudgeCode;
    }

    public Date getFirstStartDate() {
        return firstStartDate;
    }

    public void setFirstStartDate(Date firstStartDate) {
        this.firstStartDate = firstStartDate;
    }

    public String getFirstCode() {
        return firstCode;
    }

    public void setFirstCode(String firstCode) {
        this.firstCode = firstCode;
    }

    public Long getFirstTypeId() {
        return firstTypeId;
    }

    public void setFirstTypeId(Long firstTypeId) {
        this.firstTypeId = firstTypeId;
    }

    public String getFirstTypeName() {
        return firstTypeName;
    }

    public void setFirstTypeName(String firstTypeName) {
        this.firstTypeName = firstTypeName;
    }

    public Date getFirstEndDate() {
        return firstEndDate;
    }

    public void setFirstEndDate(Date firstEndDate) {
        this.firstEndDate = firstEndDate;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getFirstResultId() {
        return firstResultId;
    }

    @ReferDeserialTransfer
    public void setFirstResultId(Long firstResultId) {
        this.firstResultId = firstResultId;
    }

    public String getFirstResultName() {
        return firstResultName;
    }

    public void setFirstResultName(String firstResultName) {
        this.firstResultName = firstResultName;
    }

    public BigDecimal getFirstEndAmount() {
        return firstEndAmount;
    }

    public void setFirstEndAmount(BigDecimal firstEndAmount) {
        this.firstEndAmount = firstEndAmount;
    }

    public Date getFirstAppealDate() {
        return firstAppealDate;
    }

    public void setFirstAppealDate(Date firstAppealDate) {
        this.firstAppealDate = firstAppealDate;
    }

    public Date getFirstLastDate() {
        return firstLastDate;
    }

    public void setFirstLastDate(Date firstLastDate) {
        this.firstLastDate = firstLastDate;
    }

    public Date getFirstPayDate() {
        return firstPayDate;
    }

    public void setFirstPayDate(Date firstPayDate) {
        this.firstPayDate = firstPayDate;
    }

    public Integer getHearCount() {
        return hearCount;
    }

    public void setHearCount(Integer hearCount) {
        this.hearCount = hearCount;
    }

    @ReferSerialTransfer(referCode = "law-prosecution-case-register")
    public Long getCaseId() {
        return caseId;
    }

    @ReferDeserialTransfer
    public void setCaseId(Long caseId) {
        this.caseId = caseId;
    }

    public String getCaseName() {
        return caseName;
    }

    public void setCaseName(String caseName) {
        this.caseName = caseName;
    }

    public BigDecimal getAppealAmount() {
        return appealAmount;
    }

    public void setAppealAmount(BigDecimal appealAmount) {
        this.appealAmount = appealAmount;
    }

    public BigDecimal getThirdAmount() {
        return thirdAmount;
    }

    public void setThirdAmount(BigDecimal thirdAmount) {
        this.thirdAmount = thirdAmount;
    }

    public String getAppealAmountRemark() {
        return appealAmountRemark;
    }

    public void setAppealAmountRemark(String appealAmountRemark) {
        this.appealAmountRemark = appealAmountRemark;
    }

    public String getThirdAmountRemark() {
        return thirdAmountRemark;
    }

    public void setThirdAmountRemark(String thirdAmountRemark) {
        this.thirdAmountRemark = thirdAmountRemark;
    }

    public String getDisputeType() {
        return disputeType;
    }

    public void setDisputeType(String disputeType) {
        this.disputeType = disputeType;
    }

    public String getDisputeTypeName() {
        return disputeTypeName;
    }

    public void setDisputeTypeName(String disputeTypeName) {
        this.disputeTypeName = disputeTypeName;
    }

    public Long getPlaintiffMainId() {
        return plaintiffMainId;
    }

    public void setPlaintiffMainId(Long plaintiffMainId) {
        this.plaintiffMainId = plaintiffMainId;
    }

    public String getPlaintiffMainName() {
        return plaintiffMainName;
    }

    public void setPlaintiffMainName(String plaintiffMainName) {
        this.plaintiffMainName = plaintiffMainName;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public BigDecimal getLng() {
        return lng;
    }

    public void setLng(BigDecimal lng) {
        this.lng = lng;
    }

    public BigDecimal getLat() {
        return lat;
    }

    public void setLat(BigDecimal lat) {
        this.lat = lat;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
}
